==> vmaid-1.8.5.tar.gz: vmaid-1.8.5/dllloader/shell32.c <==
/*
    dllloader
    copyright (c) 2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#include "shell32.h"
#include "module.h"
#include "windef.h"


/******************************************************************************
*                                                                             *
*                                                                       *
*                                                                             *
******************************************************************************/
static HINSTANCE WINAPI ShellExecuteA(HWND hWnd,LPCSTR lpOperation,
			LPCSTR lpFile,LPCSTR lpParameters,LPCSTR lpDirectory,INT nShowCmd)
{
	return NULL;
}


/******************************************************************************
*                                                                             *
* Ͽ                                                                        *
*                                                                             *
******************************************************************************/
static VOID WINAPI UnknownSymbol(VOID)
{
	g_message("unknown symbol in shell32 called\n");
}


static SymbolInfo symbol_infos[]={
	{"ShellExecuteA",ShellExecuteA},
	{NULL,UnknownSymbol}
};


SymbolInfo *shell32_get_export_symbols(void)
{
	module_register("shell32.dll",symbol_infos);
	return symbol_infos;
}

==> vmaid-1.8.22.tar.gz: vmaid-1.8.22/dllloader/shell32.c <==
/*
    dllloader
    copyright (c) 2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#include "shell32.h"


/******************************************************************************
*                                                                             *
*                                                                       *
*                                                                             *
******************************************************************************/
static HINSTANCE WINAPI ShellExecuteA(HWND hWnd,LPCSTR lpOperation,
			LPCSTR lpFile,LPCSTR lpParameters,LPCSTR lpDirectory,INT nShowCmd)
{
	g_debug("ShellExecuteA");
	return NULL;
}


/******************************************************************************
*                                                                             *
* Ͽ                                                                        *
*                                                                             *
******************************************************************************/
static VOID WINAPI UnknownSymbol(VOID)
{
	g_message("unknown symbol in shell32 called");
}


static SymbolInfo symbol_infos[]={
	{"ShellExecuteA",ShellExecuteA},
	{NULL,UnknownSymbol}
};


SymbolInfo *shell32_get_export_symbols(void)
{
	return symbol_infos;
}
